#!/bin/bash
#
# filename: flac2mp3_dirs.sh
# script to convert a dir of flac audio files to mp3 files
# THIS SCRIPT IS CALLED BY flac2mp3_wrapper-dirs.sh

# Pete Nesbitt, August 2007

# concept is to build a raw wav file, then turn it into a mp3
# flac utility decodes flac to raw (.wav) file and lame converts that to mp3

# flac -d IROBOT-77_1.flac
# lame -q 0 IROBOT-77_1.wav IROBOT-77_1.mp3
# combined:
# flac -d -c IROBOT-77_1.flac |lame -q 0 - IROBOT-77_1.mp3

# exit codes:
# 0 = success
# 1 = missing flac or lame
# 2 = no flac files found to convert, or could not cd to source dir
# 3 = could not create output dir, or could not write output file
# 4 = something caused the conversion to fail


#####################
### Vars etc

# You'll want to change this:
#OUTPUT_BASE="/tmp/mp3_out"
OUTPUT_BASE="/data/media/music/albums_mp3"

# do not change:
START_PATH="`echo $PWD`"
NEW_PATH=0

#####################
### Functions
# check for flac and lame
check_required() {
 # check flac
 which flac &> /dev/null
 RET_FLAC=$?
 if [ $RET_FLAC -eq 0 ]; then
    FLAC="`which flac`"
 else
    echo "ERROR: cannot locate \"flac\" utility. Is it installed?"
    exit 1
 fi
 # check for lame
 which lame &> /dev/null
 RET_LAME=$?
 if [ $RET_LAME -eq 0 ]; then
    LAME="`which lame`"
 else
    echo "ERROR: cannot locate \"lame\" utility. Is it installed?"
    exit 1
 fi
}

# create new dir and puts mp3's in
make_dir() {
  # get current dir name
  DIR_NAME="`basename \`pwd\``"
  OUTPUT_DIR=${OUTPUT_BASE}/${DIR_NAME}
  if [ ! -d "${OUTPUT_DIR}" ];then  
   mkdir -p ${OUTPUT_DIR}
   RET_MKDIR=$?
   if [ $RET_MKDIR -ne 0 ]; then
      echo "ERROR: could not create output directory:"
      echo "       ${OUTPUT_DIR}"
      exit 3
   fi
  fi
}

# convert file:
convert_track() {
TRACK=$1
  TRACK_OUT=`echo $TRACK|sed "s/.flac$/.mp3/"`
  CONVERT_CMD="`$FLAC -d -c $TRACK |$LAME -q 0 - $TRACK_OUT`"
  $CONVERT_CMD
  RET_CONVERT=$?
  if [ $RET_CONVERT -ne 0 ]; then
     echo "ERROR: something went wrong, unable to convert file"
     echo "  ...exiting"
     exit 4
  else #mv on success. If we create in dest, then a failure (i.e. CPU overheats) may leave a broken file in with good ones.
     mv ${TRACK_OUT} ${OUTPUT_DIR}/
  fi
}

#####################
# start of work
# do we have what we need?
check_required

# create a place for the mp3's
make_dir

for TRACK_IN in `ls *.flac`
 do
   echo
   echo "CONVERTING:  $TRACK_IN to mp3"
   echo
   convert_track $TRACK_IN
   echo
   echo "Done."
   echo
   echo
   echo "------------------------------"
 done


#eof
