#!/bin/bash
#
# filename: flac2mp3_wrapper-dirs.sh
# wrapper script to convert a dir of sub-dirs containing flac audio files to mp3 files
# takes an optional arg as the source flac dir, or uses current
# calls flac2mp3_dirs.sh script to do the work

# Pete Nesbitt, August 2007

# thins is basically the same as flac2mp3.sh except it works from a higher level directory and works on the sub dirs that contain .flac files.


# concept is to build a raw wav file, then turn it into a mp3
# flac utility decodes flac to raw (.wav) file and lame converts that to mp3

#####################
### Vars etc

# edit to point to where you unpacked these files:
FLAC2MP3="/data/scripts/flac2mp3/flac2mp3_dirs.sh"
FLAC2MP3_CSS="/data/scripts/flac2mp3/flac2mp3.css"
FLAC2MP3_HTML="/data/scripts/flac2mp3/flac2mp3_html.sh"

# do not change
START_PATH="`echo $PWD`"
NEW_PATH=0
#####################



######################
# start of work

# look for $1 as top level of music dir, else use current
if [ $1 ]; then
   NEW_PATH=1
   cd $1
   RET_PATH=$?
   if [ $RET_PATH -ne 0 ]; then
      echo "ERROR: could not change to source directory:"
      echo "       $1"
      exit 2
   fi
fi

for SRC_DIR in `ls`
 # instead, you could use this to stop CPU overheating
  # for x in A B C D E F G H I J K L M N O P Q R S T U V W X Y Z;do
  # for SRC_DIR in `ls -d ${x}*`
 #OR
  #select what dirs to look in: (eg below works on dies that start with Te or Th)
  # for SRC_DIR in `ls -d T[eh]*`  OR   for SRC_DIR in `ls -d [WY]*`
 do
   if [ -d $SRC_DIR ]; then
      cd $SRC_DIR
      if [ "`ls *.flac`" ]; then
         $FLAC2MP3
         cd ../
  #sleep 600  #to let cpu cool 10 minutes (use with A B C D ....above)
      fi
   fi
 done
  #done # closes the top for loop with $x defined (use with A B C D ....above)

# fq'd in case it aliases to "cp -i", which will prompt overwrite (typical for root)
/bin/cp -f $FLAC2MP3_CSS .

echo;echo " Regenerating playlist.html"
$FLAC2MP3_HTML
echo "  ...done";echo

if [ ${NEW_PATH} -eq 1 ]; then
   cd ${START_PATH}
fi

#eof
